#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_FAST_GAMMA_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_FAST_GAMMA_HPP_INCLUDED

#include <nt2/euler/include/functions/scalar/fast_gamma.hpp>

#endif
